package com.ruoyi.business.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.business.mapper.TMiStockMapper;
import com.ruoyi.business.domain.TMiStock;
import com.ruoyi.business.service.ITMiStockService;
import com.ruoyi.common.core.text.Convert;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

/**
 * 库存Service业务层处理
 * 
 * @author wms
 * @date 2022-05-29
 */
@Service
public class TMiStockServiceImpl extends ServiceImpl<TMiStockMapper, TMiStock> implements ITMiStockService
{
    @Autowired
    private TMiStockMapper tMiStockMapper;

    /**
     * 查询库存
     * 
     * @param stockId 库存主键
     * @return 库存
     */
    @Override
    public TMiStock selectTMiStockByStockId(String stockId)
    {
        return tMiStockMapper.selectTMiStockByStockId(stockId);
    }

    /**
     * 查询库存列表
     * 
     * @param tMiStock 库存
     * @return 库存
     */
    @Override
    public List<TMiStock> selectTMiStockList(TMiStock tMiStock)
    {
        return tMiStockMapper.selectTMiStockList(tMiStock);
    }

    /**
     * 查询库存列表(不含空托)
     *
     * @param tMiStock 库存
     * @return 库存
     */
    @Override
    public List<TMiStock> selectStock(TMiStock tMiStock)
    {
        return tMiStockMapper.selectStock(tMiStock);
    }

    /**
     * 查询库存列表(空托)
     *
     * @param tMiStock 库存
     * @return 库存
     */
    @Override
    public List<TMiStock> selectStockEmpty(TMiStock tMiStock)
    {
        return tMiStockMapper.selectStockEmpty(tMiStock);
    }

    /**
     * 查询7天或12天后过期的物料
     *
     * @param tMiStock 库存
     * @return 库存
     */
    @Override
    public List<TMiStock> selectStockEkpExpireItem(TMiStock tMiStock)
    {
        return tMiStockMapper.selectStockEkpExpireItem(tMiStock);
    }

    /**
     * 新增库存
     * 
     * @param tMiStock 库存
     * @return 结果
     */
    @Override
    public int insertTMiStock(TMiStock tMiStock)
    {
        return tMiStockMapper.insertTMiStock(tMiStock);
    }

    /**
     * 修改库存
     * 
     * @param tMiStock 库存
     * @return 结果
     */
    @Override
    public int updateTMiStock(TMiStock tMiStock)
    {
        return tMiStockMapper.updateTMiStock(tMiStock);
    }

    /**
     * 定时执行任务（过期自动不合格）
     *
     * @return 结果
     */
    @Override
    public List<TMiStock> selectTMiStockExpired()
    {
        return tMiStockMapper.selectTMiStockExpired();
    }

    /**
     * 批量删除库存
     * 
     * @param stockIds 需要删除的库存主键
     * @return 结果
     */
    @Override
    public int deleteTMiStockByStockIds(String stockIds)
    {
        return tMiStockMapper.deleteTMiStockByStockIds(Convert.toStrArray(stockIds));
    }

    /**
     * 删除库存信息
     * 
     * @param stockId 库存主键
     * @return 结果
     */
    @Override
    public int deleteTMiStockByStockId(String stockId)
    {
        return tMiStockMapper.deleteTMiStockByStockId(stockId);
    }

    /**
     * 查询出库用库存列表
     *
     * @param tMiStock 库存
     * @return 库存
     */
    @Override
    public List<TMiStock> selectTMiStockOutList(TMiStock tMiStock)
    {
        return tMiStockMapper.selectTMiStockOutList(tMiStock);
    }

    /**
     * 查询出库用库存列表
     *
     * @param tMiStock 库存
     * @return 库存
     */
    @Override
    public List<TMiStock> selectTMiStockOutListByLot(TMiStock tMiStock)
    {
        return tMiStockMapper.selectTMiStockOutListByLot(tMiStock);
    }
}
